@@ -380,7 +380,6 @@ our %Modules = (
 
     'Digest::MD5' => {
         'DISTRIBUTION' => 'TODDR/Digest-MD5-2.59.tar.gz',
-        'SYNCINFO'     => 'root on Sat Dec 30 21:42:47 2023',
         'FILES'        => q[cpan/Digest-MD5],
         'EXCLUDED'     => [ 'rfc1321.txt', 'bin/md5sum.pl' ],
     },
@@ -827,7 +826,7 @@ our %Modules = (
     },
 
     'Module::CoreList' => {
-        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20240829.tar.gz',
+        'DISTRIBUTION' => 'BINGOS/Module-CoreList-5.20240920.tar.gz',
         'FILES'        => q[dist/Module-CoreList],
     },
 
@@ -1000,8 +999,8 @@ our %Modules = (
     },
 
     'Scalar::Util' => {
-        'DISTRIBUTION' => 'PEVANS/Scalar-List-Utils-1.66.tar.gz',
-        'SYNCINFO'     => 'tib on Fri Sep 20 08:05:21 2024',
+        'DISTRIBUTION' => 'PEVANS/Scalar-List-Utils-1.68.tar.gz',
+        'SYNCINFO'     => 'rich on Sun Oct 20 15:42:58 2024',
         'FILES'        => q[cpan/Scalar-List-Utils],
     },
 
